Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(287)

Unified Diff: ppapi/c/private/ppp_instance_private.h

Issue 6871040: Rename Instance_Trusted to Instance_Private, wire it up in Chrome. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix up based on review comments. Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/c/private/ppb_instance_private.h ('k') | ppapi/c/trusted/ppb_instance_trusted.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/c/private/ppp_instance_private.h
diff --git a/ppapi/c/trusted/ppp_instance_trusted.h b/ppapi/c/private/ppp_instance_private.h
similarity index 76%
rename from ppapi/c/trusted/ppp_instance_trusted.h
rename to ppapi/c/private/ppp_instance_private.h
index b010db4a3f47782700b6ea307990740fb055d1b7..e587d26e3f6cb5b53ae3736a6f42426b67cb7d3f 100644
--- a/ppapi/c/trusted/ppp_instance_trusted.h
+++ b/ppapi/c/private/ppp_instance_private.h
@@ -2,18 +2,18 @@
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-#ifndef PPAPI_C_TRUSTED_PPP_INSTANCE_TRUSTED_H_
-#define PPAPI_C_TRUSTED_PPP_INSTANCE_TRUSTED_H_
+#ifndef PPAPI_C_PRIVATE_PPP_INSTANCE_PRIVATE_H_
+#define PPAPI_C_PRIVATE_PPP_INSTANCE_PRIVATE_H_
#include "ppapi/c/pp_instance.h"
struct PP_Var;
-#define PPP_INSTANCE_TRUSTED_INTERFACE "PPP_Instance_Trusted;0.1"
+#define PPP_INSTANCE_PRIVATE_INTERFACE "PPP_Instance_Private;0.1"
/**
* @file
- * This file defines the PPP_InstanceTrusted structure; a series of functions
+ * This file defines the PPP_InstancePrivate structure; a series of functions
* that a trusted plugin may implement to provide capabilities only available
* to trusted plugins.
*
@@ -24,12 +24,12 @@ struct PP_Var;
*/
/**
* The PPP_Instance_Trusted interface contains pointers to a series of
* functions that may be implemented in a trusted plugin to provide capabilities
* that aren't possible in untrusted modules.
*/
-struct PPP_Instance_Trusted {
+struct PPP_Instance_Private {
/**
* GetInstanceObject returns a PP_Var representing the scriptable object for
* the given instance. Normally this will be a PPP_Class_Deprecated object
@@ -50,5 +50,5 @@ struct PPP_Instance_Trusted {
* @}
*/
-#endif /* PPAPI_C_TRUSTED_PPP_INSTANCE_TRUSTED_H_ */
+#endif /* PPAPI_C_PRIVATE_PPP_INSTANCE_PRIVATE_H_ */
« no previous file with comments | « ppapi/c/private/ppb_instance_private.h ('k') | ppapi/c/trusted/ppb_instance_trusted.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -24,12 +24,12 @@ struct PP_Var;
*/
/**
- * The PPP_Instance_Trusted interface contains pointers to a series of
+ * The PPP_Instance_Private interface contains pointers to a series of
* functions that may be implemented in a trusted plugin to provide capabilities
* that aren't possible in untrusted modules.
This is Rietveld 408576698